@@ -35,6 +35,7 @@ class AzIdToNameMapping(
         id: builtins.str,
         *,
         az_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
+        lambda_code: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Code] = None,
         log_retention: typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays] = None,
         ssm_parameter_prefix: typing.Optional[builtins.str] = None,
     ) -> None:
@@ -42,6 +43,7 @@ class AzIdToNameMapping(
         :param scope: -
         :param id: -
         :param az_ids: The target AZ IDs for mapping. Defaults to values for 3 zones in us-east-1. Default: ['use1-az2', 'use1-az4', 'use1-az6']
+        :param lambda_code: The lambda function code to use for the custom resource. For most use cases this should be left as the default, but in cases where the custom resource needs to be deployed through something like CloudFormation StackSets you may need to source the lambda function code from S3 or some other location because the CDK cant upload the local code to the correct asset location for the StackSet target accounts. You can use the included ``AccessKeyFunctionCodeCache`` class to cache the lambda function code in S3 and create a cross account access policy to allow the StackSet target accounts to access the code. Default: - default lambda function code
         :param log_retention: The number of days to retain log events in CloudWatch logs. Defaults to 30 days. Default: logs.RetentionDays.ONE_MONTH
         :param ssm_parameter_prefix: The prefix to use for the SSM parameter names. Defaults to ``/az-mapping/``. Default: '/az-mapping/'
         '''
@@ -51,6 +53,7 @@ class AzIdToNameMapping(
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = AzIdToNameMappingProps(
             az_ids=az_ids,
+            lambda_code=lambda_code,
             log_retention=log_retention,
             ssm_parameter_prefix=ssm_parameter_prefix,
         )
@@ -761,6 +764,7 @@ class AzIdToNameMappingFunctionCodeCacheProps(_aws_cdk_aws_s3_ceddda9d.BucketPro
     jsii_struct_bases=[],
     name_mapping={
         "az_ids": "azIds",
+        "lambda_code": "lambdaCode",
         "log_retention": "logRetention",
         "ssm_parameter_prefix": "ssmParameterPrefix",
     },
@@ -770,23 +774,28 @@ class AzIdToNameMappingProps:
         self,
         *,
         az_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
+        lambda_code: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Code] = None,
         log_retention: typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays] = None,
         ssm_parameter_prefix: typing.Optional[builtins.str] = None,
     ) -> None:
         '''The properties of a new AZ ID to name mapping.
 
         :param az_ids: The target AZ IDs for mapping. Defaults to values for 3 zones in us-east-1. Default: ['use1-az2', 'use1-az4', 'use1-az6']
+        :param lambda_code: The lambda function code to use for the custom resource. For most use cases this should be left as the default, but in cases where the custom resource needs to be deployed through something like CloudFormation StackSets you may need to source the lambda function code from S3 or some other location because the CDK cant upload the local code to the correct asset location for the StackSet target accounts. You can use the included ``AccessKeyFunctionCodeCache`` class to cache the lambda function code in S3 and create a cross account access policy to allow the StackSet target accounts to access the code. Default: - default lambda function code
         :param log_retention: The number of days to retain log events in CloudWatch logs. Defaults to 30 days. Default: logs.RetentionDays.ONE_MONTH
         :param ssm_parameter_prefix: The prefix to use for the SSM parameter names. Defaults to ``/az-mapping/``. Default: '/az-mapping/'
         '''
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__18c15575ce63eee4acf10333bc7c3ac0aabb639dfb8e41183cddd7e624e1931e)
             check_type(argname="argument az_ids", value=az_ids, expected_type=type_hints["az_ids"])
+            check_type(argname="argument lambda_code", value=lambda_code, expected_type=type_hints["lambda_code"])
             check_type(argname="argument log_retention", value=log_retention, expected_type=type_hints["log_retention"])
             check_type(argname="argument ssm_parameter_prefix", value=ssm_parameter_prefix, expected_type=type_hints["ssm_parameter_prefix"])
         self._values: typing.Dict[builtins.str, typing.Any] = {}
         if az_ids is not None:
             self._values["az_ids"] = az_ids
+        if lambda_code is not None:
+            self._values["lambda_code"] = lambda_code
         if log_retention is not None:
             self._values["log_retention"] = log_retention
         if ssm_parameter_prefix is not None:
@@ -803,6 +812,27 @@ class AzIdToNameMappingProps:
         result = self._values.get("az_ids")
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
+    @builtins.property
+    def lambda_code(self) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Code]:
+        '''The lambda function code to use for the custom resource.
+
+        For most use cases this should be left as the default, but
+        in cases where the custom resource needs to be deployed through
+        something like CloudFormation StackSets you may need to source
+        the lambda function code from S3 or some other location because
+        the CDK cant upload the local code to the correct asset location
+        for the StackSet target accounts.
+
+        You can use the included ``AccessKeyFunctionCodeCache`` class to
+        cache the lambda function code in S3 and create a cross
+        account access policy to allow the StackSet target accounts
+        to access the code.
+
+        :default: - default lambda function code
+        '''
+        result = self._values.get("lambda_code")
+        return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Code], result)
+
     @builtins.property
     def log_retention(
         self,
@@ -853,6 +883,7 @@ def _typecheckingstub__7f8e01f1331094aea4f29fcdf1c20c5b0d4600dafd77865a5c3bfc70a
     id: builtins.str,
     *,
     az_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
+    lambda_code: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Code] = None,
     log_retention: typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays] = None,
     ssm_parameter_prefix: typing.Optional[builtins.str] = None,
 ) -> None:
@@ -951,6 +982,7 @@ def _typecheckingstub__12b89de7e5433dd290acdfe05af4fbf8cd5750d22052a2fb662e2b131
 def _typecheckingstub__18c15575ce63eee4acf10333bc7c3ac0aabb639dfb8e41183cddd7e624e1931e(
     *,
     az_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
+    lambda_code: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Code] = None,
     log_retention: typing.Optional[_aws_cdk_aws_logs_ceddda9d.RetentionDays] = None,
     ssm_parameter_prefix: typing.Optional[builtins.str] = None,
 ) -> None:
